# Dirac on a Graph

A Python library that makes it easy to perform computational spectral geometry on finite graphs.

## Installation

Dirac on a Graph is available from PyPI:

	pip install dirac_graph

## Examples

[Example notebook](https://github.com/pulquero/dirac_graph/blob/main/example.ipynb) demonstrating various calculations.
